--
-- Mod: FS25_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersContractRewards by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.1.0

 

RealNumbersContractRewards = {};

function myPrintContract(text, number, textWidth, unit)
	print(string.format("%s =  %9.0f %s", text..string.rep(" ",textWidth-string.len(text)),number,"    "..unit));
end;
function myPrintFloatContract(text, number, textWidth, unit)
	print(string.format("%s =  %12.2f  %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;
function myPrintTextContract(text, text2, textWidth, unit)
	print(string.format("%s =  %s %s", text..string.rep(" ",textWidth-string.len(text)),text2,"    "..unit));
end;

function RealNumbersContractRewards:loadMap(name)

	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;
	local textWidth											= 40;
	local missionName										= " ";
	local missionClassName									= " ";
	local isDebug											= true;
	local missionfield										= {};

	RN.contractRewards 										= {};
	RN.contractRewards.priceFluctuations					= {};

	DebugUtil.printTableRecursively(g_currentMission.mapOverlayGenerator,"_",0,2);    
--	DebugUtil.printTableRecursively(g_currentMission.mapOverlayGenerator.fillTypeManager,"_",0,2);    
--[[
    if g_currentMission.mapOverlayGenerator.fillTypeManager.fillTypes ~= nil then
	
		for i, fillType in pairs(g_currentMission.mapOverlayGenerator.fillTypeManager.fillTypes) do
	--		local fillTypeName = tostring(g_currentMission.mapOverlayGenerator.fillTypeManager.fillTypes[i].name);
			local fillTypeName = tostring(fillType.name);
			RN.contractRewards.priceFluctuations[fillTypeName]	= {};
			if fillType.economy ~= nil then
				for j = 1,12 do
					if fillType.economy.factors[j] ~= nil then
						RN.contractRewards.priceFluctuations[fillTypeName][j] = fillType.economy.factors[j];
					else
						RN.contractRewards.priceFluctuations[fillTypeName][j] = 1;
					end;
				end;
			end;
		end;
	else
		print("RealNumbersContractReward: fillTypeManager.fillTypes does not exists");
	
	end;
	
	RN.notRunYetRealNumbersContractRewards 					= true;
	RN.upStartRealNumbersContractRewards 					= true;

	RN.contractRewards.rewardPerHa  						= {};	-- field work
	RN.contractRewards.rewardPerTree  						= {};	-- field work
	RN.contractRewards.rewardPerRock  						= {};	-- field work
	RN.contractRewards.REIMBURSEMENT_PER_HA 				= {};	-- reimbursement for fertilizer and herbicide
	RN.contractRewards.REWARD_PER_OBJECT 					= {};	-- transport mission
	RN.contractRewards.vehicleBaseCostScale 				= {};	-- scaling of fixed equipment rent in missions
	RN.contractRewards.vehicleUseCostPerHa 					= {};	-- hectare based deduction from using rented equipment
	RN.contractRewards.vehicleUseCost 						= {};	-- Original vehicleUseCost
	RN.contractRewards.randomScaleMin						= {};
	RN.contractRewards.randomScaleMax						= {};
	RN.contractRewards.priceScales 							= {};
	RN.contractRewards.notRunYet 							= true; -- Run definition of original vehicleUseCost

	print("\n --- RealNumbersContractRewards.lua started --- \n");

	if g_missionManager.missionTypes ~= nil then

		for i, mission in pairs(g_missionManager.missionTypes) do				-- define default values
			missionName = mission.name;
			if missionName ~= "harvestMission" then
				RN.contractRewards.rewardPerHa[missionName] 		= 100;		-- default RLN value	field work
			end;
			RN.contractRewards.REIMBURSEMENT_PER_HA[missionName] 	= 0;		-- default RLN value    reimbursement for fertilizer and herbicide
			RN.contractRewards.vehicleBaseCostScale[missionName]	= 0.5;		-- default RLN value
			RN.contractRewards.vehicleUseCostPerHa[missionName] 	= 5;		-- default RLN value
			RN.contractRewards.randomScaleMin[missionName] 			= 0.9;		-- default RLN value
			RN.contractRewards.randomScaleMax[missionName] 			= 1.1;		-- default RLN value
			
		end;
	end;


	RN.contractRewards.REIMBURSEMENT_PER_HA["herbicideMission"]		= 36000 * g_sprayTypeManager.nameToSprayType["HERBICIDE"].litersPerSecond
																*	g_fillTypeManager.nameToFillType["HERBICIDE"].pricePerLiter;
	RN.contractRewards.REIMBURSEMENT_PER_HA["fertilizeMission"]	= 36000 * g_sprayTypeManager.nameToSprayType["FERTILIZER"].litersPerSecond
																*	g_fillTypeManager.nameToFillType["FERTILIZER"].pricePerLiter

	SprayMission.REIMBURSEMENT_PER_HA = RN.contractRewards.REIMBURSEMENT_PER_HA["spray"];


	local modSettingsDir = getUserProfileAppPath() .. "modSettings";
	if modSettingsDir == nil then
		print(" ");
		print("modSettingsDir undefined");
		print(" ");
	end;

	local savegameIndex = 0;
	if g_currentMission.missionInfo.savegameIndex ~= nil then
		savegameIndex = g_currentMission.missionInfo.savegameIndex;
	end;
	local RNmodSettingsDir = modSettingsDir .. "/RealLifeNumbers/savegame" .. savegameIndex;

	local myContractsXML = RNmodSettingsDir.."/my_Contracts.xml";
	if fileExists(myContractsXML) then
		print("\n --- my XML file is used --- \n")
	else
		print("xml file does not exist for this savegame");
	end;


	if fileExists(myContractsXML) then

		local xmlFile = loadXMLFile("missions", myContractsXML);
		print("Loading file:");
		print(myContractsXML);
		print(" ");

		local i = 0;
		while true do
			local xmlKey = string.format("missionTypes.missionType(%d)", i);
			if not hasXMLProperty(xmlFile, xmlKey) then
			print(" end of file or does not have xml property");
				break;
			end;
			local missionName = getXMLString(xmlFile, xmlKey .. "#name");
			if isDebug then print(" ");end;
			if isDebug then print("Mission type : "..missionName);end;
			if getXMLInt(xmlFile, xmlKey .. "#vehicleUseCostPerHa") ~= nil then
				RN.contractRewards.vehicleBaseCostScale[missionName] = getXMLFloat(xmlFile, xmlKey .. "#vehicleBaseCostScale");
				RN.contractRewards.vehicleUseCostPerHa[missionName] = getXMLFloat(xmlFile, xmlKey .. "#vehicleUseCostPerHa");
				if isDebug then print("vehicleUseCostPerHa : "..RN.contractRewards.vehicleUseCostPerHa[missionName]);end;
			end;

			local xmlKey2 = string.format("missionTypes.missionType(%d).reward", i);
			if hasXMLProperty(xmlFile, xmlKey2) then
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerHa ") ~= nil then
					RN.contractRewards.rewardPerHa[missionName] = getXMLInt(xmlFile, xmlKey2.. "#rewardPerHa");
					if isDebug then print("rewardPerHa : "..RN.contractRewards.rewardPerHa[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerTree") ~= nil then
					RN.contractRewards.rewardPerTree[missionName] = getXMLFloat(xmlFile, xmlKey2.. "#rewardPerTree");
					if isDebug then print("rewardPerTree : "..RN.contractRewards.rewardPerTree[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerRock") ~= nil then
					RN.contractRewards.rewardPerRock[missionName] = getXMLInt(xmlFile, xmlKey2.. "#rewardPerRock");
					if isDebug then print("rewardPerRock : "..RN.contractRewards.rewardPerRock[missionName]);end;
				end;
			end;
			i = i + 1;
		end;
	end;

	if g_missionManager.missionTypes ~= nil then

		for i, mission in pairs(g_missionManager.missionTypes) do
			missionName = mission.classObject.NAME;
			missionClassName = mission.classObject.className;

			print(" ");
			print("Mission type                             :      "..missionName);
			print(" ");
			if ((g_missionManager.missionTypes[i].data.rewardPerHa  ~= nil) and (missionName ~= "harvestMission")) then
				g_missionManager.missionTypes[i].data.rewardPerHa   = RN.contractRewards.rewardPerHa[missionName];
				myPrintContract("Reward per ha",g_missionManager.missionTypes[i].data.rewardPerHa,textWidth,currency.."/ha");
				myPrintFloatContract("Scaling factor for equipment deduction",RN.contractRewards.vehicleBaseCostScale[missionName],textWidth," ");
				myPrintContract("Rented equipment deduction per ha",RN.contractRewards.vehicleUseCostPerHa[missionName],textWidth,currency.."/ha");
			end;
			if g_missionManager.missionTypes[i].data.rewardPerTree ~= nil then
				g_missionManager.missionTypes[i].data.rewardPerTree  = RN.contractRewards.rewardPerTree[missionName];
				myPrintFloatContract("Reward per tree",g_missionManager.missionTypes[i].data.rewardPerTree,textWidth,currency.."/m");
			end;
			if g_missionManager.missionTypes[i].data.rewardPerRock    ~= nil then
				g_missionManager.missionTypes[i].data.rewardPerRock     = RN.contractRewards.rewardPerRock [missionName];
				myPrintContract("Reward per rock",g_missionManager.missionTypes[i].data.rewardPerRock ,textWidth,currency.."/object");
			end;
--				if isDebug then DebugUtil.printTableRecursively(v.classObject,"_",0,3); end;
		end;
	else
		print("No missions defined");
	end;
--]]
	print("\n --- RealNumbersContractRewards.lua updates every 10 min --- \n");
end;


function RealNumbersContractRewards:keyEvent(unicode, sym, modifier, isDown)
--[[
	local fruitTypeIndex 				= 0;
	local contractFruitType 			= {};
	local missionFillTypeIndex			= 0;
	local missionFillTypeName			= "Undefined";
	local fruitName 					= "Undefined";
	local missionfield 					= {};
	local fieldArea 					= 0;
	local contractLiters				= 0;
	local contractPricePer1000Liters 	= 0;
	local normalPricePer1000Liters 		= 0;
	local contractTransportReward		= 0;
	local contractCropReward			= 0;
	local farmlandId 						= 0;
	local textWidth						= 40;
	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;

	local currentPeriod	= g_currentMission.environment.currentPeriod;
	local currentMonth 	= (g_currentMission.environment.currentPeriod + 2) % 12;	 -- March is apparently month 1
	if currentMonth == 0 then currentMonth = 12; end;

	if Input.isKeyPressed(Input.KEY_lalt) and Input.isKeyPressed(Input.KEY_r) and Input.isKeyPressed(Input.KEY_c) then
		if g_missionManager.missions ~= nil then

			print("\n --- RealNumbersContractRewards.lua lAlt-rc pressed --- \n");
			print("\nMissions on map at this moment\n");

			for i, mission in pairs(g_missionManager.missions) do
				local missionName = mission.type.name;
				print(" ");
				print(string.upper(missionName));
				fruitName = "Undefined";
				missionFillTypeName = "Undefined";
				missionFillTypeIndex = 0;
				if missionName == "transport" then
					if mission.reward ~= nil then
						myPrintContract("Reward for transport",mission.reward,textWidth,currency);
					end;
				elseif missionName == "supplyTransport" then
					missionFillTypeName = g_fillTypeManager:getFillTypeNameByIndex(mission.fillType);
					contractLiters = mission.contractLiters;
					myPrintTextContract("Goods to transport",missionFillTypeName,textWidth," ");
					local seasonPriceScale = RN.contractRewards.priceFluctuations[missionFillTypeName][currentPeriod];
					local pricePerLiter = g_fillTypeManager.nameToFillType[missionFillTypeName].pricePerLiter;
					local seasonPricePer1000Liters 	= 1000 * seasonPriceScale * pricePerLiter;
					contractPricePer1000Liters 		= 1000 * mission.pricePerLitre;
					normalPricePer1000Liters 		= 1000 * g_fillTypeManager.nameToFillType[missionFillTypeName].pricePerLiter;
					contractTransportReward = RN.contractRewards.UNIT_REWARD[missionName]
											* math.sqrt(mission.contractLiters/RN.contractRewards.UNIT_VOLUME[missionName]);
					contractCropReward = contractLiters * contractPricePer1000Liters/1000;
					if mission.reward ~= nil then
						myPrintContract("Month",currentMonth,textWidth," ");
						myPrintContract("Volume to transport",contractLiters,textWidth,"Liters");
						myPrintContract("Goods reward",contractCropReward,textWidth,currency);
						myPrintContract("Transport reward",contractTransportReward,textWidth,currency);
						myPrintContract("Total reward",mission.reward,textWidth,currency);
						myPrintContract("Contract price per 1000 L",contractPricePer1000Liters,textWidth,currency);
						myPrintContract("Seasonal price per 1000 L",seasonPricePer1000Liters,textWidth,currency);
						myPrintContract("Annual mean price per 1000 L",normalPricePer1000Liters,textWidth,currency);
					end;
				elseif missionName == "treeTransport" then
					local numTrees = mission.numTrees;
					contractTransportReward = RN.contractRewards.UNIT_REWARD[missionName] * numTrees;
					myPrintContract("Trees to transport",numTrees,textWidth," ");
					myPrintContract("Reward per tree",RN.contractRewards.UNIT_REWARD[missionName],textWidth,currency);
					myPrintContract("Total reward",contractTransportReward,textWidth,currency);
				elseif missionName == "deadwood" then
					local numDeadTrees = mission.numDeadTrees ;
					contractTransportReward = RN.contractRewards.UNIT_REWARD[missionName] * numDeadTrees;
					myPrintContract("Dead trees to transport",numDeadTrees,textWidth," ");
					myPrintContract("Reward per dead tree",RN.contractRewards.UNIT_REWARD[missionName],textWidth,currency);
					myPrintContract("Total reward",contractTransportReward,textWidth,currency);
				elseif missionName == "destructibleRocks" then
					local numRocks = #mission.rocks ;
					contractReward = RN.contractRewards.UNIT_REWARD[missionName] * numRocks;
					myPrintContract("Rocks to destroy",numRocks,textWidth," ");
					myPrintContract("Reward per rock",RN.contractRewards.UNIT_REWARD[missionName],textWidth,currency);
					myPrintContract("Total reward",contractReward,textWidth,currency);
				else
				
					if mission.fruitTypeIndex ~= nil then
					    fruitTypeIndex = mission.fruitTypeIndex;
					else
					    fruitTypeIndex = 0;
					end;
					if mission.field ~= nil then
						missionfield = mission.field;
						fieldArea = missionfield.areaHa ;
						farmlandId = missionfield.farmland.id;
					
						if mission.fillTypeIndex ~= nil then
							missionFillTypeIndex = mission.fillTypeIndex;
						else
							missionFillTypeIndex = 0;
						end;
						if ((missionFillTypeIndex > 0) and (g_fillTypeManager:getFillTypeNameByIndex(missionFillTypeIndex) ~= nil)) then
							missionFillTypeName = g_fillTypeManager:getFillTypeNameByIndex(missionFillTypeIndex);
						else
							missionFillTypeName = "Undefined";
						end;


						if fruitTypeIndex == 0 then
							fruitName = "Undefined";

							if missionfield.plannedFruitTypeIndex ~= nil then
								if missionfield.plannedFruitTypeIndex ~= 0 then
									fruitTypeIndex = missionfield.plannedFruitTypeIndex;
									if g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex) ~= nil then
										contractFruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
										if contractFruitType.name ~= nil then
											fruitName = string.upper(contractFruitType.name);		-- not defined in multiplayer games
										end;
									end;
								end;
								if (missionName == "sowMission") then
									if g_fruitTypeManager.nameToFruitType[fruitName] ~= nil then
										RN.contractRewards.REIMBURSEMENT_PER_HA[missionName]	= 10000 * g_fruitTypeManager.nameToFruitType[fruitName].seedUsagePerSqm
																										* g_fillTypeManager.nameToFillType["SEEDS"].pricePerLiter;
									else
										RN.contractRewards.REIMBURSEMENT_PER_HA[missionName]	= 0;
									end;
								end;
							end;
						else
							contractFruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
							if (contractFruitType == nil) then -- added 2022-07-21
								print("\n --- Undefined contractFruitType, fruitIndex : "..fruitTypeIndex);
								print(" --- Using wheat instead \n");
								contractFruitType = g_fruitTypeManager:getFruitTypeByName("WHEAT");
							end
							fruitName = string.upper(contractFruitType.name);
						end;

						if fruitName ~= "Undefined" then print("Mission fruitType : "..fruitName);end;
						if missionFillTypeName ~= "Undefined" then print("Mission fillType : "..missionFillTypeName);end;
						print(" ");
						myPrintContract("Farmland id",farmlandId,textWidth," ");
						myPrintFloatContract("Crop area",fieldArea,textWidth,"ha");
						if mission.rewardPerHa ~= nil then
							myPrintContract("Reward per ha",mission.rewardPerHa,textWidth,currency.."/ha");
						end;
						if mission.reward ~= nil then
							myPrintFloatContract("Payment",mission.reward,textWidth,currency);
						end;
						if mission.vehicleUseCost ~= nil then
							myPrintFloatContract("Rented equipment deduction",mission.vehicleUseCost,textWidth,currency);
						end;
						if (missionName == "fertilize") then
							myPrintFloatContract("Fertilizer cost per ha",RN.contractRewards.REIMBURSEMENT_PER_HA[missionName],textWidth,currency.."/ha");
							myPrintFloatContract("Fertilizer cost",fieldArea * RN.contractRewards.REIMBURSEMENT_PER_HA[missionName],textWidth,currency);
							local netReward = mission.reward - fieldArea * RN.contractRewards.REIMBURSEMENT_PER_HA[missionName];
							myPrintFloatContract("Net reward with own equipment",netReward,textWidth,currency);
						end;
						if (missionName == "spray") then
							myPrintFloatContract("Hebicide cost per ha",RN.contractRewards.REIMBURSEMENT_PER_HA[missionName],textWidth,currency.."/ha");
							myPrintFloatContract("Hebicide cost ",fieldArea * RN.contractRewards.REIMBURSEMENT_PER_HA[missionName],textWidth,currency);
							local netReward = mission.reward - fieldArea * RN.contractRewards.REIMBURSEMENT_PER_HA[missionName];
							myPrintFloatContract("Net reward with own equipment",netReward,textWidth,currency);
						end;
						if (missionName == "sow")  then
							myPrintFloatContract("Seed cost per ha",RN.contractRewards.REIMBURSEMENT_PER_HA[missionName],textWidth,currency.."/ha");
							myPrintFloatContract("Seed cost",fieldArea * RN.contractRewards.REIMBURSEMENT_PER_HA[missionName],textWidth,currency);
							local netReward = mission.reward - fieldArea * RN.contractRewards.REIMBURSEMENT_PER_HA[missionName];
							myPrintFloatContract("Net reward with own equipment",netReward,textWidth,currency);
						end;
					end;
				end;
			end;
			print("\n --- RealNumbersContractRewards.lua lAlt-rc pressed --- \n");
		else
			print("No missions defined");
		end;
	end;
--]]
end;
function RealNumbersContractRewards:update(dt)
--[[
	local minute 				= g_currentMission.environment.currentMinute;
	local currentPeriod			= g_currentMission.environment.currentPeriod;
	local runMinute 			= minute % 10; -- remainder
	local missionFillTypeName	= " ";
	local fruitTypeIndex 		= 0;
	local contractLiters		= 0;
	local contractFruitType 	= {};
	local fruitName 			= " ";
	local missionfield 			= {};
	local fieldArea 			= 0;
	local fieldId 				= 0;
	local goodsValue			= 0;
	local isHost 				= true;
	local ymin 					= 1.0;
	local ymax					= 1.0;
	local isDebug				= false;


	local currentMonth = (g_currentMission.environment.currentPeriod + 2) % 12;	 -- March is apparently month 1
	if currentMonth == 0 then currentMonth = 12; end;

	if g_missionManager.missions ~= nil then					-- No missions when RLN loads
		if RN.contractRewards.notRunYet then
			if isDebug then print(" "); end;
			for i, mission in pairs(g_missionManager.missions) do
				local missionName = mission.type.name;
				if isDebug then print(missionName); end;
				if missionName == "supplyTransport" then
					if g_fillTypeManager:getFillTypeNameByIndex(mission.fillType) ~= nil then
						missionFillTypeName = g_fillTypeManager:getFillTypeNameByIndex(mission.fillType);
					else
						missionFillTypeName = "Undefined";
					end;
					if mission.contractLiters ~= nil then
						contractLiters = mission.contractLiters;
					else
						contractLiters = 0;
					end;
					if isDebug then print("Reward = "..mission.reward.."; fillType = "..missionFillTypeName.."; Contract liters = "..contractLiters); end;


				elseif mission.field ~= nil then
					missionfield = mission.field;
					fieldId = missionfield.fieldId;
					if mission.vehicleUseCost ~= nil then
						RN.contractRewards.vehicleUseCost[fieldId] = mission.vehicleUseCost;
					else
						RN.contractRewards.vehicleUseCost[fieldId] = 0;
					end;
					if isDebug then print("fieldId = "..fieldId..";  VehicleUseCost = "..RN.contractRewards.vehicleUseCost[fieldId]); end;
				end;
			end;
			if isDebug then  print(" "); end;
			RN.contractRewards.notRunYet = false;
		end;
	end;


	if runMinute ~= 5 then RN.notRunYetRealNumbersContractRewards = true; end;
	if runMinute == 5 or RN.upStartRealNumbersContractRewards then
		if RN.notRunYetRealNumbersContractRewards then
			if g_missionManager.missions ~= nil then
				for i, mission in pairs(g_missionManager.missions) do
					local missionName = mission.type.name;

					if missionName == "transport" then
						if (mission.numObjects ~= nil) and (RN.contractRewards.REWARD_PER_OBJECT[missionName] ~= nil) then
							local numObjects = mission.numObjects;
							local objectFeeTotal = numObjects * RN.contractRewards.REWARD_PER_OBJECT[missionName];
							local totalTransportFee = objectFeeTotal;
							if mission.reward ~= nil then mission.reward = totalTransportFee; end;
						else
							if mission.reward ~= nil then mission.reward = 0; end;
						end;
					elseif missionName == "treeTransport" then
						if (mission.numTrees ~= nil) and (RN.contractRewards.REWARD_PER_OBJECT[missionName] ~= nil) then
							local numTrees = mission.numTrees;
							local objectFeeTotal = numTrees * RN.contractRewards.REWARD_PER_OBJECT[missionName];
							local totalTransportFee = objectFeeTotal;
							if mission.reward ~= nil then mission.reward = totalTransportFee; end;
						else
							if mission.reward ~= nil then mission.reward = 0; end;
						end;
					elseif missionName == "deadwood" then
						if (mission.numDeadTrees  ~= nil) and (RN.contractRewards.REWARD_PER_OBJECT[missionName] ~= nil) then
							local numDeadTrees  = mission.numDeadTrees ;
							local objectFeeTotal = numDeadTrees  * RN.contractRewards.REWARD_PER_OBJECT[missionName];
							local totalTransportFee = objectFeeTotal;
							if mission.reward ~= nil then mission.reward = totalTransportFee; end;
						else
							if mission.reward ~= nil then mission.reward = 0; end;
						end;
					elseif missionName == "destructibleRocks" then
						if (#mission.rocks  ~= nil) and (RN.contractRewards.REWARD_PER_OBJECT[missionName] ~= nil) then
							local numRocks  = #mission.rocks;
							local objectFeeTotal = numRocks  * RN.contractRewards.REWARD_PER_OBJECT[missionName];
							local totalTransportFee = objectFeeTotal;
							if mission.reward ~= nil then mission.reward = totalTransportFee; end;
						else
							if mission.reward ~= nil then mission.reward = 0; end;
						end;
					elseif missionName == "supplyTransport" then
						ymin = RN.contractRewards.randomScaleMin[missionName];
						ymax = RN.contractRewards.randomScaleMax[missionName];
						local randomNumber = (ymax - ymin) * math.random() + ymin;
						if g_fillTypeManager:getFillTypeNameByIndex(mission.fillType) ~= nil then
							missionFillTypeName = g_fillTypeManager:getFillTypeNameByIndex(mission.fillType);
							local seasonPriceScale = RN.contractRewards.priceFluctuations[missionFillTypeName][currentPeriod];
							local pricePerLiter = g_fillTypeManager.nameToFillType[missionFillTypeName].pricePerLiter;
							mission.pricePerLitre = randomNumber * seasonPriceScale * pricePerLiter;
							if (mission.contractLiters ~= nil) and (mission.pricePerLitre ~= nil) then
								goodsValue = mission.contractLiters * mission.pricePerLitre;
								if (RN.contractRewards.UNIT_REWARD[missionName] ~= nil) and (RN.contractRewards.UNIT_VOLUME[missionName]~= nil) then
									mission.reward = goodsValue + RN.contractRewards.UNIT_REWARD[missionName]
															* math.sqrt(mission.contractLiters/RN.contractRewards.UNIT_VOLUME[missionName]);
								else
									if mission.reward ~= nil then mission.reward = 0;end;
								end;
							end;
						else
							if mission.reward ~= nil then mission.reward = 0;end;
							if mission.pricePerLitre ~= nil then mission.pricePerLitre = 0;end;
						end;
--						print(missionFillTypeName);
--						DebugUtil.printTableRecursively(mission,"_",0,0);
--						print(missionFillTypeName);
--						DebugUtil.printTableRecursively(mission.sellingStation,"_",0,1);

					else
						missionFillType = mission.fillType;
						if mission.field ~= nil then
							missionfield = mission.field;
							fieldArea = missionfield.fieldArea;
							fieldId = missionfield.fieldId;
							if missionfield.fruitType == nil then
								fruitTypeIndex = nil;
								fruitName = "noFruitName";
								if missionfield.plannedFruit ~= nil then
									fruitTypeIndex = missionfield.plannedFruit;
									if g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex) ~= nil then
										contractFruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
										if contractFruitType.name ~= nil then
											fruitName = string.upper(contractFruitType.name);				-- not defined in multiplayer games
										end;
									end;
									if (missionName == "sow") then
										if g_fruitTypeManager.nameToFruitType[fruitName] ~= nil then
											RN.contractRewards.REIMBURSEMENT_PER_HA[missionName]	= 10000 * g_fruitTypeManager.nameToFruitType[fruitName].seedUsagePerSqm
																											* g_fillTypeManager.nameToFillType["SEEDS"].pricePerLiter;
										else
											RN.contractRewards.REIMBURSEMENT_PER_HA[missionName]	= 0;
										end;
									end;
								end;
							else
								fruitTypeIndex = missionfield.fruitType;
								contractFruitType = g_fruitTypeManager:getFruitTypeByIndex(fruitTypeIndex);
								if (contractFruitType == nil) then  -- added 2022-07-21
									print("\n --- Undefined contractFruitType, fruitIndex : "..fruitTypeIndex);
									print(" --- Using wheat instead \n");
									contractFruitType = g_fruitTypeManager:getFruitTypeByName("WHEAT");
								end
								fruitName = string.upper(contractFruitType.name);
							end;
							if (mission.rewardPerHa ~= nil) and (RN.contractRewards.rewardPerHa [missionName] ~= nil) then
								mission.rewardPerHa = RN.contractRewards.rewardPerHa [missionName];
							end;
							if (missionName == "mow_bale") and (g_fillTypeManager:getFillTypeNameByIndex(missionFillType) ~= nil) then
								missionFillTypeName = g_fillTypeManager:getFillTypeNameByIndex(missionFillType);
								if (missionFillTypeName == "SILAGE") and (RN.contractRewards.rewardPerHa _SILAGE[missionName] ~= nil) then
									mission.rewardPerHa = RN.contractRewards.rewardPerHa _SILAGE[missionName];
								end;
								if (missionFillTypeName == "DRYGRASS_WINDROW") and (RN.contractRewards.rewardPerHa _HAY[missionName] ~= nil) then
									mission.rewardPerHa = RN.contractRewards.rewardPerHa _HAY[missionName];
								end;
								if (missionFillTypeName == "DRYGRASS") and (RN.contractRewards.rewardPerHa _HAY[missionName] ~= nil) then
									mission.rewardPerHa = RN.contractRewards.rewardPerHa _HAY[missionName];
								end;
							end;

--							if missionName == "harvest" then
--								if fieldArea < RN.contractRewards.SMALL_FIELD[missionName] then
--									mission.rewardPerHa = RN.contractRewards.rewardPerHa _SMALL[missionName];
--								end;
--								if fieldArea > RN.contractRewards.LARGE_FIELD[missionName] then
--									mission.rewardPerHa = RN.contractRewards.rewardPerHa _SMALL[missionName];
--								end;
--							end;
							
							
							if mission.vehicleUseCost ~= nil then
								RN.contractRewards.vehicleUseCost[fieldId] = mission.vehicleUseCost;					-- added 220320 - 09:03
								if isDebug then print(missionName); end;
								if isDebug then print("fieldArea = "..fieldArea); end;
								if RN.contractRewards.vehicleUseCost[fieldId] ~= nil then
									if isDebug then print("fieldId = "..fieldId.." vehicleUseCost = "..RN.contractRewards.vehicleUseCost[fieldId]); end;
									if RN.contractRewards.vehicleBaseCostScale[missionName] ~= nil then
										if isDebug then print("fieldId = "..fieldId.." vehicleBaseCostScale = "..RN.contractRewards.vehicleBaseCostScale[missionName]); end;
										if RN.contractRewards.vehicleUseCostPerHa[missionName] ~= nil then
											if isDebug then print("fieldId = "..fieldId.." vehicleUseCostPerHa = "..RN.contractRewards.vehicleUseCostPerHa[missionName]); end;
											mission.vehicleUseCost = RN.contractRewards.vehicleBaseCostScale[missionName] * RN.contractRewards.vehicleUseCost[fieldId]
																	+ fieldArea * RN.contractRewards.vehicleUseCostPerHa[missionName];
										else
											print(" ")
											print(missionName);
											print("fieldArea = "..fieldArea);
											print("fieldId = "..fieldId);
											print("vehicleUseCostPerHa is not defined");
											print(" ")
										end;
									else
										print(" ")
										print(missionName);
										print("fieldArea = "..fieldArea);
										print("fieldId = "..fieldId);
										print("vehicleBaseCostScale is not defined");
										print(" ")
									end;
								else
									print(" ")
									print(missionName);
									print("fieldArea = "..fieldArea);
									print("fieldId = "..fieldId);
									print("vehicleUseCost is not defined");
									print(" ")
								end;
							end;
							if (mission.reward ~= nil) and (mission.rewardPerHa ~= nil) then
								mission.reward = fieldArea * mission.rewardPerHa;
							end;
							if ((missionName == "fertilize") or (missionName == "spray")) then
								mission.reimbursementPerHa = 0;
								if (RN.contractRewards.rewardPerHa [missionName] ~= nil) and (RN.contractRewards.REIMBURSEMENT_PER_HA[missionName] ~= nil) then
									mission.reward = fieldArea * (RN.contractRewards.rewardPerHa [missionName] + RN.contractRewards.REIMBURSEMENT_PER_HA[missionName]);
								else
									mission.reward = 0;
									print(missionName);
									print("rewardPerHa  or REIMBURSEMENT_PER_HA not defined");
								end;
							end;
							if (missionName == "sow") then
								if (RN.contractRewards.rewardPerHa [missionName] ~= nil) and (RN.contractRewards.REIMBURSEMENT_PER_HA[missionName] ~= nil) then
									mission.reward = fieldArea * (RN.contractRewards.rewardPerHa [missionName] + RN.contractRewards.REIMBURSEMENT_PER_HA[missionName]);
								else
									mission.reward = 0;
									print(missionName);
									print("rewardPerHa  or REIMBURSEMENT_PER_HA not defined");
								end;
							end;
						end;
					end;
				end;
			else
				print("No missions defined");
			end;
		end;
		RN.notRunYetRealNumbersContractRewards = false;
		RN.upStartRealNumbersContractRewards = false;
	end;
--]]
end;
function RealNumbersContractRewards:draw()
end;
function RealNumbersContractRewards:deleteMap()
end;
function RealNumbersContractRewards:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersContractRewards);







