--
-- Mod: FS25_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersLeasi8ng by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com
-- All rights reserved.
-- Version 1.0.0.0


RealNumbersLeasing = {};

function print_r (t, indent, done)
  done = done or {}
  indent = indent or ''
  local nextIndent -- Storage for next indentation value
  for key, value in pairs (t) do
    if type (value) == "table" and not done [value] then
      nextIndent = nextIndent or
          (indent .. string.rep(' ',string.len(tostring (key))+2))
          -- Shortcut conditional allocation
      done [value] = true
      print (indent .. "[" .. tostring (key) .. "] => Table {");
      print  (nextIndent .. "{");
      print_r (value, nextIndent .. string.rep(' ',2), done)
      print  (nextIndent .. "}");
    else
      print  (indent .. "[" .. tostring (key) .. "] => " .. tostring (value).."")
    end
  end
end

function RealNumbersLeasing:loadMap(name)

	print("\n --- RealNumbersLeasing.lua started --- \n");
	RN.notRunYetRealNumbersLeasing = true;
	RN.upStartRealNumbersLeasing = true;

 -- Short term leasing parameters

	RN.DEFAULT_RUNNING_LEASING_FACTOR 	= 0.0002;	-- default RLN value = 0
	RN.PER_DAY_LEASING_FACTOR 			= 0.001;	-- default RLN value = 0.001 (0.1 % of purchase price per day)
	RN.DEFAULT_LEASING_DEPOSIT_FACTOR 	= 0.0001;	-- default RLN value = 0

-- Long term leasing parameters

	RN.item_runningLeasingFactor_1		= 0.0002;   -- Running leasingfactor per item price range 1	(cost per hour)
	RN.item_runningLeasingFactor_2		= 0.00015;  -- Running leasingfactor per item price range 1	(cost per hour)
	RN.item_runningLeasingFactor_3		= 0.0001;   -- Running leasingfactor per item price range 1	(cost per hour)
	RN.item_runningLeasingFactor_4		= 0.00005;  -- Running leasingfactor per item price range 1 (cost per hour)
	RN.item_leasingUpperPriceLimit_1	= 50000;    -- Upper price range interval 1
	RN.item_leasingUpperPriceLimit_2	= 100000;   -- Upper price range interval 1
	RN.item_leasingUpperPriceLimit_3	= 250000;   -- Upper price range interval 1

	for i, v in pairs(g_storeManager.items) do
		if v.runningLeasingFactor   ~= nil then
			v.runningLeasingFactor = DEFAULT_RUNNING_LEASING_FACTOR;
		end;
	end;

--[[
	print("\n Default values \n");
	print("EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR = "..EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR);
	print("EconomyManager.PER_DAY_LEASING_FACTOR = "..EconomyManager.PER_DAY_LEASING_FACTOR);
	print("EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR = "..EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR);
	print("EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER = "..EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER);
	
	EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR = RN.DEFAULT_RUNNING_LEASING_FACTOR;
	EconomyManager.PER_DAY_LEASING_FACTOR = RN.PER_DAY_LEASING_FACTOR;
	EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR = RN.DEFAULT_LEASING_DEPOSIT_FACTOR;
	EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER = 0.0010;
	
	print("\n New values \n");
	print("EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR = "..EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR);
	print("EconomyManager.PER_DAY_LEASING_FACTOR = "..EconomyManager.PER_DAY_LEASING_FACTOR);
	print("EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR = "..EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR);
	print("EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER = "..EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER);	
--]]	
	print("\n --- RealNumbersLeasing.lua updates every 10 min --- \n");
end;


function RealNumbersLeasing:keyEvent(unicode, sym, modifier, isDown)
end;

function RealNumbersLeasing:update(dt)
--[[
	local minute = g_currentMission.environment.currentMinute;
	local runMinute = minute % 10; -- remainder
	if runMinute ~= 6 then RN.notRunYetRealNumbersLeasing = true; end;
	if runMinute == 6 or RN.upStartRealNumbersLeasing then
		if RN.notRunYetRealNumbersLeasing then

			if g_storeManager.items ~= nil then
				for i,items in pairs(g_storeManager.items) do
					if items.allowLeasing then
						if items.runningLeasingFactor ~= nil then			
							if items.price < RN.item_leasingUpperPriceLimit_1 then
								items.runningLeasingFactor = RN.item_runningLeasingFactor_1;
							elseif items.price < RN.item_leasingUpperPriceLimit_2 then
								items.runningLeasingFactor = RN.item_runningLeasingFactor_2;
							elseif items.price < RN.item_leasingUpperPriceLimit_3 then
								items.runningLeasingFactor = RN.item_runningLeasingFactor_3;
							else
								items.runningLeasingFactor = RN.item_runningLeasingFactor_4;
							end;
						end;
					end;
				end;
			end;

			EconomyManager.DEFAULT_RUNNING_LEASING_FACTOR = RN.DEFAULT_RUNNING_LEASING_FACTOR;
			EconomyManager.PER_DAY_LEASING_FACTOR = RN.PER_DAY_LEASING_FACTOR;
			EconomyManager.DEFAULT_LEASING_DEPOSIT_FACTOR = RN.DEFAULT_LEASING_DEPOSIT_FACTOR;
			EconomyManager.MAX_DAILYUPKEEP_MULTIPLIER = 0.0010;
		end;
		RN.notRunYetRealNumbersLeasing = false;
		RN.upStartRealNumbersLeasing = false;
	end;
--]]
end;
function RealNumbersLeasing:draw()
end;
function RealNumbersLeasing:deleteMap()
end;
function RealNumbersLeasing:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersLeasing);







