--
-- Mod: FS25_RealLifeNumbers by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- Script: RealNumbersContractRewards by Kaj-Aage Henneberg "Ki", ArmChairFarming
-- e-mail: kaj-aage.henneberg@outlook.dk
-- Download: www.modhoster.com or kingmods.net
-- All rights reserved.
-- Version 1.0.0.1



RealNumbersContractRewards = {};

function myPrintContract(text, number, textWidth, unit)
	print(string.format("%s =  %9.0f %s", text..string.rep(" ",textWidth-string.len(text)),number,"    "..unit));
end;
function myPrintFloatContract(text, number, textWidth, unit)
	print(string.format("%s =  %12.2f  %s", text..string.rep(" ",textWidth-string.len(text)),number, unit));
end;
function myPrintTextContract(text, text2, textWidth, unit)
	print(string.format("%s =  %s %s", text..string.rep(" ",textWidth-string.len(text)),text2,"    "..unit));
end;

function RealNumbersContractRewards:loadMap(name)

	local currency = "€";	-- or  "$" or "£"
	local gameMoneyUnit = g_i18n.moneyUnit;
	if gameMoneyUnit == 1 then
        currency = "€";
	elseif gameMoneyUnit == 2 then
        currency = "$";
	elseif gameMoneyUnit == 3 then
        currency = "£";
	end;
	local textWidth											= 40;
	local missionName										= " ";
	local missionClassName									= " ";
	local isDebug											= false;
	local missionfield										= {};
	RN.contractRewards 										= {};
	RN.contractRewards.priceFluctuations					= {};
	RN.notRunYetRealNumbersContractRewards 					= true;
	RN.upStartRealNumbersContractRewards 					= true;
	RN.contractRewards.rewardPerHa  						= {};	-- field work
	RN.contractRewards.rewardPerBale  						= {};	-- field work
	RN.contractRewards.rewardPerTree  						= {};	-- forest work
	RN.contractRewards.penaltyPerTree  						= {};	-- forest work
	RN.contractRewards.rewardPerRock  						= {};	-- field work
	RN.contractRewards.penaltyPerRock  						= {};	-- field work
	RN.contractRewards.REIMBURSEMENT_PER_HA 				= {};	-- reimbursement for fertilizer and herbicide
	RN.contractRewards.REWARD_PER_OBJECT 					= {};	-- transport mission
	RN.contractRewards.vehicleBaseCostScale 				= {};	-- scaling of fixed equipment rent in missions
	RN.contractRewards.vehicleUseCostPerHa 					= {};	-- hectare based deduction from using rented equipment
	RN.contractRewards.vehicleUseCost 						= {};	-- Original vehicleUseCost
	RN.contractRewards.randomScaleMin						= {};
	RN.contractRewards.randomScaleMax						= {};
	RN.contractRewards.priceScales 							= {};
	RN.contractRewards.notRunYet 							= true; -- Run definition of original vehicleUseCost

	print("\n --- RealNumbersContractRewards.lua started --- \n");


	local modSettingsDir = getUserProfileAppPath() .. "modSettings";
	if modSettingsDir == nil then
		print(" ");
		print("modSettingsDir undefined");
		print(" ");
	end;

	local savegameIndex = 0;
	if g_currentMission.missionInfo.savegameIndex ~= nil then
		savegameIndex = g_currentMission.missionInfo.savegameIndex;
	end;
	local RNmodSettingsDir = modSettingsDir .. "/RealLifeNumbers/savegame" .. savegameIndex;

	local myContractsXML = RNmodSettingsDir.."/my_Contracts.xml";
	if fileExists(myContractsXML) then
		print("\n --- my XML file is used --- \n")
	else
		print("xml file does not exist for this savegame");
	end;


	if fileExists(myContractsXML) then

		local xmlFile = loadXMLFile("missions", myContractsXML);
		print("Loading file:");
		print(myContractsXML);
		print(" ");

		local i = 0;
		while true do
			local xmlKey = string.format("missionTypes.missionType(%d)", i);
			if not hasXMLProperty(xmlFile, xmlKey) then
			print(" end of file or does not have xml property");
				break;
			end;
			local missionName = getXMLString(xmlFile, xmlKey .. "#name");
			if isDebug then print(" ");end;
			if isDebug then print("Mission type : "..missionName);end;
			if getXMLInt(xmlFile, xmlKey .. "#vehicleUseCostPerHa") ~= nil then
				RN.contractRewards.vehicleBaseCostScale[missionName] = getXMLFloat(xmlFile, xmlKey .. "#vehicleBaseCostScale");
				RN.contractRewards.vehicleUseCostPerHa[missionName] = getXMLFloat(xmlFile, xmlKey .. "#vehicleUseCostPerHa");
				if isDebug then print("vehicleUseCostPerHa : "..RN.contractRewards.vehicleUseCostPerHa[missionName]);end;
			end;

			local xmlKey2 = string.format("missionTypes.missionType(%d).reward", i);
			if hasXMLProperty(xmlFile, xmlKey2) then
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerHa") ~= nil then
					RN.contractRewards.rewardPerHa[missionName] = getXMLInt(xmlFile, xmlKey2.. "#rewardPerHa");
					if isDebug then print("rewardPerHa : "..RN.contractRewards.rewardPerHa[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerBale") ~= nil then
					RN.contractRewards.rewardPerBale[missionName] = getXMLInt(xmlFile, xmlKey2.. "#rewardPerBale");
					if isDebug then print("rewardPerBale : "..RN.contractRewards.rewardPerBale[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerTree") ~= nil then
					RN.contractRewards.rewardPerTree[missionName] = getXMLFloat(xmlFile, xmlKey2.. "#rewardPerTree");
					if isDebug then print("rewardPerTree : "..RN.contractRewards.rewardPerTree[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#rewardPerRock") ~= nil then
					RN.contractRewards.rewardPerRock[missionName] = getXMLInt(xmlFile, xmlKey2.. "#rewardPerRock");
					if isDebug then print("rewardPerRock : "..RN.contractRewards.rewardPerRock[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#penaltyPerTree") ~= nil then
					RN.contractRewards.penaltyPerTree[missionName] = getXMLFloat(xmlFile, xmlKey2.. "#penaltyPerTree");
					if isDebug then print("penaltyPerTree : "..RN.contractRewards.penaltyPerTree[missionName]);end;
				end;
				if getXMLInt(xmlFile, xmlKey2.. "#penaltyPerRock") ~= nil then
					RN.contractRewards.penaltyPerRock[missionName] = getXMLInt(xmlFile, xmlKey2.. "#penaltyPerRock");
					if isDebug then print("penaltyPerRock : "..RN.contractRewards.penaltyPerRock[missionName]);end;
				end;
			end;
			i = i + 1;
		end;
	end;

	if g_missionManager.missionTypes ~= nil then

		for i, mission in pairs(g_missionManager.missionTypes) do
			missionName = mission.classObject.NAME;
			missionClassName = mission.classObject.className;
			if missionName == "treeTransportMission" then
--				g_missionManager.missionTypes[i].data.rewardPerTree = 1;
				g_missionManager.missionTypes[i].data.rewardPerTree  = RN.contractRewards.rewardPerTree[missionName];
				g_missionManager.missionTypes[i].data.penaltyPerTree = RN.contractRewards.penaltyPerTree[missionName];
				myPrintFloatContract(missionName,g_missionManager.missionTypes[i].data.rewardPerTree,textWidth,currency.."/tree");
			elseif missionName == "deadwoodMission" then
--				g_missionManager.missionTypes[i].data.rewardPerTree = 1;
				g_missionManager.missionTypes[i].data.rewardPerTree  = RN.contractRewards.rewardPerTree[missionName];
				myPrintFloatContract(missionName,g_missionManager.missionTypes[i].data.rewardPerTree,textWidth,currency.."/tree");
			elseif missionName == "destructibleRockMission" then
--				g_missionManager.missionTypes[i].data.rewardPerRock = 1;
				g_missionManager.missionTypes[i].data.rewardPerRock   = RN.contractRewards.rewardPerRock[missionName];
				g_missionManager.missionTypes[i].data.penaltyPerRock  = RN.contractRewards.penaltyPerRock[missionName];
				myPrintContract(missionName,g_missionManager.missionTypes[i].data.rewardPerRock ,textWidth,currency.."/rock");
			elseif missionName == "baleWrapMission" then
--				g_missionManager.missionTypes[i].data.rewardPerBale = 1;
				g_missionManager.missionTypes[i].data.rewardPerBale   = RN.contractRewards.rewardPerBale[missionName];
				myPrintContract(missionName,g_missionManager.missionTypes[i].data.rewardPerBale,textWidth,currency.."/bale");
			else
--				g_missionManager.missionTypes[i].data.rewardPerHa = 1;
				g_missionManager.missionTypes[i].data.rewardPerHa   = RN.contractRewards.rewardPerHa[missionName];
				myPrintContract(missionName,g_missionManager.missionTypes[i].data.rewardPerHa,textWidth,currency.."/ha");
			end;
		end;
	else
		print("No missions defined");
	end;
	print("\n --- ContractRewards redefined --- \n");
end;

function RealNumbersContractRewards:keyEvent(unicode, sym, modifier, isDown)
end;
function RealNumbersContractRewards:update(dt)
	local minute 				= g_currentMission.environment.currentMinute;
	local currentPeriod			= g_currentMission.environment.currentPeriod;
	local runMinute 			= minute % 10; -- remainder
	local missionFillTypeName	= " ";
	local fruitTypeIndex 		= 0;
	local contractLiters		= 0;
	local contractFruitType 	= {};
	local fruitName 			= " ";
	local missionfield 			= {};
	local fieldArea 			= 0;
	local fieldId 				= 0;
	local goodsValue			= 0;
	local isHost 				= true;
	local ymin 					= 1.0;
	local ymax					= 1.0;
	local isDebug				= false;
	local spots                 = {};


	local currentMonth = (g_currentMission.environment.currentPeriod + 2) % 12;	 -- March is apparently month 1
	if currentMonth == 0 then currentMonth = 12; end;

	if runMinute ~= 5 then RN.notRunYetRealNumbersContractRewards = true; end;
	if runMinute == 5 or RN.upStartRealNumbersContractRewards then
		if RN.notRunYetRealNumbersContractRewards then

			if g_missionManager.missionTypes ~= nil then

				if isDebug then print("\n --- RealNumbersContractRewards.lua updating --- \n"); end;
				for i, mission in pairs(g_missionManager.missions) do
					local missionName = mission.type.classObject.NAME;
					missionClassName = mission.type.classObject.className;
					if isDebug then print(missionName); end;
					if missionName == "treeTransportMission" then
						g_missionManager.missions[i].type.data.rewardPerTree  = RN.contractRewards.rewardPerTree[missionName];
						g_missionManager.missions[i].type.data.penaltyPerTree = RN.contractRewards.penaltyPerTree[missionName];
                        spots = g_missionManager.missions[i].type.data.spots;
						local numberOfTrees = #spots
						g_missionManager.missions[i].reward = numberOfTrees * g_missionManager.missions[i].type.data.rewardPerTree;
						if isDebug then print("rewardPerTree = "..g_missionManager.missions[i].type.data.rewardPerTree); end;
						if isDebug then print("reward = "..g_missionManager.missions[i].reward); end;
					elseif missionName == "deadwoodMission" then
						g_missionManager.missions[i].type.data.rewardPerTree  = RN.contractRewards.rewardPerTree[missionName];
						spots = g_missionManager.missions[i].type.data.spots;
						local numberOfTrees = #spots
						g_missionManager.missions[i].reward = numberOfTrees * g_missionManager.missions[i].type.data.rewardPerTree;
						if isDebug then print("rewardPerTree = "..g_missionManager.missions[i].type.data.rewardPerTree); end;
						if isDebug then print("reward = "..g_missionManager.missions[i].reward); end;
					elseif missionName == "destructibleRockMission" then
						g_missionManager.missions[i].type.data.rewardPerRock   = RN.contractRewards.rewardPerRock[missionName];
						g_missionManager.missions[i].type.data.penaltyPerRock  = RN.contractRewards.penaltyPerRock[missionName];
						spots = g_missionManager.missions[i].type.data.spots;
						local numberOfRocks = #spots;
						g_missionManager.missions[i].reward = numberOfRocks * g_missionManager.missions[i].type.data.rewardPerRock;
						if isDebug then print("rewardPerRock = "..g_missionManager.missions[i].type.data.rewardPerRock); end;
						if isDebug then print("reward = "..g_missionManager.missions[i].reward); end;
					elseif missionName == "baleWrapMission" then
						g_missionManager.missions[i].type.data.rewardPerBale   = RN.contractRewards.rewardPerBale[missionName];
						if isDebug then print(g_missionManager.missions[i].type.data.rewardPerBale); end;
					else
						g_missionManager.missions[i].type.data.rewardPerHa   = RN.contractRewards.rewardPerHa[missionName];
						if isDebug then print("rewardPerHa = "..g_missionManager.missions[i].type.data.rewardPerHa); end;
					end;
				end;
			else
				if isDebug then print("No missions defined"); end;
			end;
		end;
        RN.notRunYetRealNumbersContractRewards = false;
		RN.upStartRealNumbersContractRewards = false;
	end;
end;
function RealNumbersContractRewards:draw()
end;
function RealNumbersContractRewards:deleteMap()
end;
function RealNumbersContractRewards:mouseEvent(posX, posY, isDown, isUp, button)
end;

addModEventListener(RealNumbersContractRewards);

